@@ -4,7 +4,7 @@ from functools import partial
 
 import regex as re
 
-from ..helpers import inside_ignored_block
+from ..helpers import child_of_ignored_block
 from ..settings import Config
 
 
@@ -115,7 +115,7 @@ def format_attributes(config: Config, html: str, match: re.match) -> str:
     """Spread long attributes over multiple lines."""
     # check that we are not inside an ignored block
     if (
-        inside_ignored_block(config, html, match)
+        child_of_ignored_block(config, html, match)
         or len(match.group(3).strip()) < config.max_attribute_length
     ):
         return match.group()
@@ -132,11 +132,24 @@ def format_attributes(config: Config, html: str, match: re.match) -> str:
     for attr_grp in re.finditer(
         config.attribute_pattern, match.group(3).strip(), re.VERBOSE
     ):
-
         attrib_name = attr_grp.group(1)
         is_quoted = attr_grp.group(2) and attr_grp.group(2)[0] in ["'", '"']
         quote = attr_grp.group(2)[0] if is_quoted else '"'
-        attrib_value = attr_grp.group(2).strip("\"'") if attr_grp.group(2) else None
+
+        attrib_value = None
+
+        if attr_grp.group(2) and attr_grp.group(2)[0] == attr_grp.group(2)[-1]:
+            if attr_grp.group(2)[0] == "'":
+                attrib_value = attr_grp.group(2).strip("'")
+
+            elif attr_grp.group(2)[0] == '"':
+                attrib_value = attr_grp.group(2).strip('"')
+
+            else:
+                attrib_value = attr_grp.group(2)
+        else:
+            attrib_value = attr_grp.group(2)
+
         standalone = attr_grp.group(3)
 
         quote_length = 1
@@ -184,7 +197,6 @@ def format_attributes(config: Config, html: str, match: re.match) -> str:
             attributes.append(
                 (attrib_name or "") + (attrib_value or "") + (standalone or "")
             )
-
     attribute_string = ("\n" + spacing).join([x for x in attributes if x])
 
     close = match.group(4)
