@@ -116,7 +116,7 @@ def load_project_settings(src: Path, config: Optional[str]) -> Dict:
     pyproject_file = find_pyproject(src)
 
     if pyproject_file:
-        content = tomllib.load(pyproject_file.open("rb"))
+        content = tomllib.loads(pyproject_file.read_text(encoding="utf8"))
         try:
             return {**djlint_content, **content["tool"]["djlint"]}  # type: ignore
         except KeyError:
@@ -272,7 +272,7 @@ class Config:
         self.ignore: str = str(ignore or djlint_settings.get("ignore", ""))
 
         self.files: Optional[List[str]] = djlint_settings.get("files", None)
-        self.stdin = "-" in src and self.files is None
+        self.stdin = False
 
         # codes to exclude
         profile_dict: Dict[str, List[str]] = {
@@ -506,8 +506,8 @@ class Config:
             rf"""
             (?:
                 (
-                    (?:\w|-|\.)+ | required | checked
-                ) # attribute name
+                    (?:\w|-|\.|\:|@)+ | required | checked
+                )? # attribute name
                 (?:  [ ]*?=[ ]*? # followed by "="
                     (
                         \"[^\"]*? # double quoted attribute
@@ -538,6 +538,7 @@ class Config:
             """
             + r"""
             | {{.*?}}
+            | {\#.*?\#}
             | {%.*?%})
         """
         )
